@@ -8,6 +8,7 @@ import sys
 import indexclient.client as client
 
 from gen3.utils import DEFAULT_BACKOFF_SETTINGS
+from gen3.auth import Gen3Auth
 
 
 class Gen3Index:
@@ -16,20 +17,25 @@ class Gen3Index:
     A class for interacting with the Gen3 Index services.
 
     Args:
-        endpoint (str): The URL of the data commons.
-        auth_provider (Gen3Auth): A Gen3Auth class instance.
+        endpoint (str): public endpoint for reading/querying indexd - only necessary if auth_provider not provided
+        auth_provider (Gen3Auth): A Gen3Auth class instance or indexd basic creds tuple
 
     Examples:
         This generates the Gen3Index class pointed at the sandbox commons while
         using the credentials.json downloaded from the commons profile page.
 
-        >>> endpoint = "https://nci-crdc-demo.datacommons.io"
-        ... auth = Gen3Auth(endpoint, refresh_file="credentials.json")
-        ... sub = Gen3Submission(endpoint, auth)
+        >>> auth = Gen3Auth(refresh_file="credentials.json")
+        ... index = Gen3Index(auth)
 
     """
 
-    def __init__(self, endpoint, auth_provider=None, service_location="index"):
+    def __init__(self, endpoint=None, auth_provider=None, service_location="index"):
+        # legacy interface required endpoint as 1st arg
+        if endpoint and isinstance(endpoint, Gen3Auth):
+            auth_provider = endpoint
+            endpoint = None
+        if auth_provider and isinstance(auth_provider, Gen3Auth):
+            endpoint = auth_provider.endpoint
         endpoint = endpoint.strip("/")
         # if running locally, indexd is deployed by itself without a location relative
         # to the commons
@@ -615,7 +621,7 @@ class Gen3Index:
             json["authz"] = authz
 
         response = self.client._put(
-            "index/blank/",
+            "index/blank",
             guid,
             headers={"content-type": "application/json"},
             params=params,
