@@ -1,3 +1,4 @@
+import itertools
 import json
 import requests
 import pandas as pd
@@ -24,28 +25,26 @@ class Gen3Submission:
     Supports GraphQL queries through Peregrine.
 
     Args:
-        endpoint (str): The URL of the data commons.
         auth_provider (Gen3Auth): A Gen3Auth class instance.
 
     Examples:
         This generates the Gen3Submission class pointed at the sandbox commons while
         using the credentials.json downloaded from the commons profile page.
 
-        >>> endpoint = "https://nci-crdc-demo.datacommons.io"
-        ... auth = Gen3Auth(endpoint, refresh_file="credentials.json")
-        ... sub = Gen3Submission(endpoint, auth)
+        >>> auth = Gen3Auth(refresh_file="credentials.json")
+        ... sub = Gen3Submission(auth)
 
     """
 
-    def __init__(self, endpoint, auth_provider):
-        self._auth_provider = auth_provider
-        self._endpoint = endpoint
+    def __init__(self, endpoint=None, auth_provider=None):
+        # auth_provider legacy interface required endpoint as 1st arg
+        self._auth_provider = auth_provider or endpoint
+        self._endpoint = self._auth_provider.endpoint
 
     def __export_file(self, filename, output):
         """Writes an API response to a file."""
-        outfile = open(filename, "w")
-        outfile.write(output)
-        outfile.close
+        with open(filename, "w") as outfile:
+            outfile.write(output)
         print("\nOutput written to file: " + filename)
 
     ### Program functions
@@ -202,7 +201,9 @@ class Gen3Submission:
         return output.json()
 
     def delete_record(self, program, project, uuid):
-        """Delete a record from a project.
+        """
+        Delete a record from a project.
+
         Args:
             program (str): The program to delete from.
             project (str): The project to delete from.
@@ -213,13 +214,107 @@ class Gen3Submission:
 
             >>> Gen3Submission.delete_record("DCF", "CCLE", uuid)
         """
-        api_url = "{}/api/v0/submission/{}/{}/entities/{}".format(
-            self._endpoint, program, project, uuid
+        return self.delete_records(program, project, [uuid])
+
+    def delete_records(self, program, project, uuids, batch_size=100):
+        """
+        Delete a list of records from a project.
+
+        Args:
+            program (str): The program to delete from.
+            project (str): The project to delete from.
+            uuids (list): The list of uuids of the records to delete
+            batch_size (int, optional, default: 100): how many records to delete at a time
+
+        Examples:
+            This deletes a list of records from the CCLE project in the sandbox commons.
+
+            >>> Gen3Submission.delete_records("DCF", "CCLE", ["uuid1", "uuid2"])
+        """
+        api_url = "{}/api/v0/submission/{}/{}/entities".format(
+            self._endpoint, program, project
         )
-        output = requests.delete(api_url, auth=self._auth_provider)
-        output.raise_for_status()
+        for i in itertools.count():
+            uuids_to_delete = uuids[batch_size * i : batch_size * (i + 1)]
+            if len(uuids_to_delete) == 0:
+                break
+            output = requests.delete(
+                "{}/{}".format(api_url, ",".join(uuids_to_delete)),
+                auth=self._auth_provider,
+            )
+            try:
+                output.raise_for_status()
+            except requests.exceptions.HTTPError:
+                print(
+                    "\n{}\nFailed to delete uuids: {}".format(
+                        output.text, uuids_to_delete
+                    )
+                )
+                raise
         return output
 
+    def delete_node(self, program, project, node_name, batch_size=100, verbose=True):
+        """
+        Delete all records for a node from a project.
+
+        Args:
+            program (str): The program to delete from.
+            project (str): The project to delete from.
+            node_name (str): Name of the node to delete
+            batch_size (int, optional, default: 100): how many records to query and delete at a time
+            verbose (bool, optional, default: True): whether to print progress logs
+
+        Examples:
+            This deletes a node from the CCLE project in the sandbox commons.
+
+            >>> Gen3Submission.delete_node("DCF", "CCLE", "demographic")
+        """
+        return self.delete_nodes(
+            program, project, [node_name], batch_size, verbose=verbose
+        )
+
+    def delete_nodes(
+        self, program, project, ordered_node_list, batch_size=100, verbose=True
+    ):
+        """
+        Delete all records for a list of nodes from a project.
+
+        Args:
+            program (str): The program to delete from.
+            project (str): The project to delete from.
+            ordered_node_list (list): The list of nodes to delete, in reverse graph submission order
+            batch_size (int, optional, default: 100): how many records to query and delete at a time
+            verbose (bool, optional, default: True): whether to print progress logs
+
+        Examples:
+            This deletes a list of nodes from the CCLE project in the sandbox commons.
+
+            >>> Gen3Submission.delete_nodes("DCF", "CCLE", ["demographic", "subject", "experiment"])
+        """
+        project_id = f"{program}-{project}"
+        for node in ordered_node_list:
+            if verbose:
+                print(node, end="", flush=True)
+            first_uuid = ""
+            while True:
+                query_string = f"""{{
+                    {node} (first: {batch_size}, project_id: "{project_id}") {{
+                        id
+                    }}
+                }}"""
+                res = self.query(query_string)
+                uuids = [x["id"] for x in res["data"][node]]
+                if len(uuids) == 0:
+                    break  # all done
+                if first_uuid == uuids[0]:
+                    raise Exception("Failed to delete. Exiting")
+                first_uuid = uuids[0]
+                if verbose:
+                    print(".", end="", flush=True)
+                self.delete_records(program, project, uuids, batch_size)
+            if verbose:
+                print()
+
     def export_record(self, program, project, uuid, fileformat, filename=None):
         """Export a single record into json.
 
@@ -287,7 +382,7 @@ class Gen3Submission:
     ### Query functions
 
     def query(self, query_txt, variables=None, max_tries=1):
-        """Execute a GraphQL query against a data commons.
+        """Execute a GraphQL query against a Data Commons.
 
         Args:
             query_txt (str): Query text.
@@ -296,7 +391,7 @@ class Gen3Submission:
 
         Examples:
             This executes a query to get the list of all the project codes for all the projects
-            in the data commons.
+            in the Data Commons.
 
             >>> query = "{ project(first:0) { code } }"
             ... Gen3Submission.query(query)
